@@ -1,10 +1,12 @@
 package Dist::Zilla::PluginBundle::INGY;
+{
+  $Dist::Zilla::PluginBundle::INGY::VERSION = '0.001';
+}
 
 use Moose;
 use Moose::Autobox;
 use Dist::Zilla 2.100922; # TestRelease
 with 'Dist::Zilla::Role::PluginBundle::Easy';
-with 'Dist::Zilla::Role::PluginBundle::Config::Slicer';
 
 
 use Dist::Zilla::PluginBundle::Basic;
@@ -67,7 +69,7 @@ sub configure {
     } else {
       $self->add_plugins([
         'Git::NextVersion' => {
-          version_regexp => '^([0-9]+\.[0-9]+(?:\.[0-9]+)?)$',
+          version_regexp => '^([0-9]+\.[0-9]+)$',
         }
       ]);
     }
@@ -75,7 +77,7 @@ sub configure {
 
   $self->add_plugins(qw(
     ReadmeFromPod
-    OurPkgVersion
+    PkgVersion
     MetaConfig
     MetaJSON
     NextRelease
@@ -85,7 +87,7 @@ sub configure {
   qw(
     PodSyntaxTests
     Test::Compile
-    Test::ReportPrereqs
+    ReportVersions::Tiny
   ));
 
   $self->add_plugins(
